@@ -4,7 +4,6 @@ describe 'watcher::api' do
 
   let :params do
     { :watcher_client_password => 'password',
-      :manage_service    => true,
       :enabled           => true,
       :package_ensure    => 'latest',
     }
@@ -36,7 +35,7 @@ describe 'watcher::api' do
 
         it 'configures watcher-api service' do
           is_expected.to contain_service('watcher-api').with(
-            :ensure     => (params[:manage_service] && params[:enabled]) ? 'running' : 'stopped',
+            :ensure     => params[:enabled] ? 'running' : 'stopped',
             :name       => platform_params[:api_service_name],
             :enable     => params[:enabled],
             :hasstatus  => true,
@@ -51,7 +50,7 @@ describe 'watcher::api' do
 
     context 'with default api configuration' do
       it 'should configure the api configurations section when enabled' do
-        is_expected.to contain_watcher_config('api/port').with_value('9322')
+        is_expected.to contain_watcher_config('api/port').with_value(9322)
         is_expected.to contain_watcher_config('api/max_limit').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('api/host').with_value('0.0.0.0')
         is_expected.to contain_watcher_config('api/workers').with_value(2)
@@ -63,30 +62,12 @@ describe 'watcher::api' do
       before do
         params.merge!({
           :manage_service => false,
-          :enabled        => false })
+        })
       end
 
-      it 'configures watcher-api service' do
-        is_expected.to contain_service('watcher-api').with(
-          :ensure     => nil,
-          :name       => platform_params[:api_service_name],
-          :enable     => false,
-          :hasstatus  => true,
-          :hasrestart => true,
-          :tag        => ['watcher-service',
-                          'watcher-db-manage-create_schema',
-                          'watcher-db-manage-upgrade'],
-        )
+      it 'should not configure watcher-api service' do
+        is_expected.to_not contain_service('watcher-api')
       end
-
-      it 'should not configure the api configurations section when disabled' do
-        is_expected.to_not contain_watcher_config('api/port')
-        is_expected.to_not contain_watcher_config('api/max_limit')
-        is_expected.to_not contain_watcher_config('api/host')
-        is_expected.to_not contain_watcher_config('api/workers')
-        is_expected.to_not contain_watcher_config('api/enable_ssl_api')
-      end
-
     end
 
     context 'watcher clients auth section with default parameters' do
@@ -145,10 +126,10 @@ describe 'watcher::api' do
       end
 
       let :pre_condition do
-        "include ::apache
-         include ::watcher::db
+        "include apache
+         include watcher::db
          class { 'watcher': }
-         class { '::watcher::keystone::authtoken':
+         class { 'watcher::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -171,10 +152,10 @@ describe 'watcher::api' do
       end
 
       let :pre_condition do
-        "include ::apache
-         include ::watcher::db
+        "include apache
+         include watcher::db
          class { 'watcher': }
-         class { '::watcher::keystone::authtoken':
+         class { 'watcher::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
